@@ -1,4 +1,4 @@
-/* $Id: global.c 4395 2009-07-12 03:36:58Z astyanax $ */
+/* $Id: global.c 4408 2009-09-03 23:29:14Z astyanax $ */
 /**************************************************************************
  *   global.c                                                             *
  *                                                                        *
@@ -36,9 +36,6 @@ sigjmp_buf jump_buf;
 bool jump_buf_main = FALSE;
 	/* Have we set jump_buf so that we return to main() after a
 	 * SIGWINCH? */
-bool use_undo = FALSE;
-	/* Are we actually using the undo code - disabled by default
-	   as the undo code is too unstable */
 #endif
 
 #ifndef DISABLE_WRAPJUSTIFY
@@ -55,7 +52,7 @@ char *last_search = NULL;
 char *last_replace = NULL;
 	/* The last replacement string we searched for. */
 
-long flags = 0;
+unsigned flags[4] = {0, 0, 0, 0};
 	/* Our flag containing the states of all global options. */
 WINDOW *topwin;
 	/* The top portion of the window, where we display the version
@@ -781,7 +778,7 @@ void shortcut_init(bool unjustify)
     add_to_funcs(DO_UNINDENT, MMAIN, N_("Unindent Text"),
 	IFSCHELP(nano_unindent_msg), FALSE, NOVIEW);
 
-    if (use_undo) {
+    if (ISSET(UNDOABLE)) {
 	add_to_funcs(DO_UNDO, MMAIN, N_("Undo"),
 	    IFSCHELP(nano_undo_msg), FALSE, NOVIEW);
 
@@ -1069,7 +1066,7 @@ void shortcut_init(bool unjustify)
     add_to_sclist(MMAIN, "M-6", DO_COPY_TEXT, 0, TRUE);
     add_to_sclist(MMAIN, "M-}", DO_INDENT_VOID, 0, TRUE);
     add_to_sclist(MMAIN, "M-{", DO_UNINDENT, 0, TRUE);
-    if (use_undo) {
+    if (ISSET(UNDOABLE)) {
 	add_to_sclist(MMAIN, "M-U", DO_UNDO, 0, TRUE);
  	add_to_sclist(MMAIN, "M-E", DO_REDO, 0, TRUE);
     }
@@ -1082,10 +1079,10 @@ void shortcut_init(bool unjustify)
     add_to_sclist(MALL, "kleft", DO_LEFT, 0, TRUE);
     add_to_sclist(MMAIN, "^Q", XON_COMPLAINT, 0, TRUE);
     add_to_sclist(MMAIN, "^S", XOFF_COMPLAINT, 0, TRUE);
-    add_to_sclist(MMAIN, "^P", DO_UP_VOID, 0, TRUE);
-    add_to_sclist(MMAIN, "kup", DO_UP_VOID, 0, TRUE);
-    add_to_sclist(MMAIN, "^N", DO_DOWN_VOID, 0, TRUE);
-    add_to_sclist(MMAIN, "kdown", DO_DOWN_VOID, 0, TRUE);
+    add_to_sclist(MMAIN|MBROWSER, "^P", DO_UP_VOID, 0, TRUE);
+    add_to_sclist(MMAIN|MBROWSER, "kup", DO_UP_VOID, 0, TRUE);
+    add_to_sclist(MMAIN|MBROWSER, "^N", DO_DOWN_VOID, 0, TRUE);
+    add_to_sclist(MMAIN|MBROWSER, "kdown", DO_DOWN_VOID, 0, TRUE);
     add_to_sclist(MALL, "^A", DO_HOME, 0, TRUE);
     add_to_sclist(MALL, "khome", DO_HOME, 0, TRUE);
     add_to_sclist(MALL, "^E", DO_END, 0, TRUE);
@@ -1167,6 +1164,7 @@ void shortcut_init(bool unjustify)
     add_to_sclist(MMAIN, "M-M", DO_TOGGLE, USE_MOUSE, TRUE);
     add_to_sclist(MMAIN, "M-N", DO_TOGGLE, NO_CONVERT, TRUE);
     add_to_sclist(MMAIN, "M-Z", DO_TOGGLE, SUSPEND, TRUE);
+    add_to_sclist(MMAIN, "M-$", DO_TOGGLE, SOFTWRAP, TRUE);
 #endif
     add_to_sclist(MGOTOLINE, "^T",  GOTOTEXT_MSG, 0, FALSE);
     add_to_sclist(MINSERTFILE|MEXTCMD, "M-F",  NEW_BUFFER_MSG, 0, FALSE);
@@ -1379,6 +1377,8 @@ char *flagtostr(int flag)
             return N_("No conversion from DOS/Mac format");
         case SUSPEND:
             return N_("Suspension");
+        case SOFTWRAP:
+            return N_("Soft line wrapping");
         default:
             return "?????";
     }
