@@ -1,4 +1,4 @@
-/* $Id: proto.h 4395 2009-07-12 03:36:58Z astyanax $ */
+/* $Id: proto.h 4407 2009-09-03 05:45:13Z astyanax $ */
 /**************************************************************************
  *   proto.h                                                              *
  *                                                                        *
@@ -41,7 +41,7 @@ extern ssize_t wrap_at;
 extern char *last_search;
 extern char *last_replace;
 
-extern long flags;
+extern unsigned flags[4];
 extern WINDOW *topwin;
 extern WINDOW *edit;
 extern WINDOW *bottomwin;
@@ -270,7 +270,7 @@ bool close_buffer(void);
 #endif
 filestruct *read_line(char *buf, filestruct *prevnode, bool
 	*first_line_ins, size_t buf_len);
-void read_file(FILE *f, const char *filename, bool undoable);
+void read_file(FILE *f, int fd, const char *filename, bool undoable);
 int open_file(const char *filename, bool newfie, FILE **f);
 char *get_next_filename(const char *name, const char *suffix);
 void do_insertfile(
@@ -765,7 +765,7 @@ void onekey(const char *keystroke, const char *desc, size_t len);
 void reset_cursor(void);
 void edit_draw(filestruct *fileptr, const char *converted, int
 	line, size_t start);
-void update_line(filestruct *fileptr, size_t index);
+int update_line(filestruct *fileptr, size_t index);
 bool need_horizontal_update(size_t pww_save);
 bool need_vertical_update(size_t pww_save);
 void edit_scroll(scroll_dir direction, ssize_t nlines);
