@@ -1,4 +1,4 @@
-/* $Id: rcfile.c 4396 2009-07-12 06:13:36Z astyanax $ */
+/* $Id: rcfile.c 4402 2009-08-17 07:52:10Z astyanax $ */
 /**************************************************************************
  *   rcfile.c                                                             *
  *                                                                        *
@@ -92,6 +92,7 @@ static const rcoption rcopts[] = {
     {"undo", 0},
     {"whitespace", 0},
     {"wordbounds", WORD_BOUNDS},
+    {"softwrap", SOFTWRAP},
 #endif
     {NULL, 0}
 };
@@ -909,15 +910,6 @@ void parse_rcfile(FILE *rcstream
 	option = ptr;
 	ptr = parse_next_word(ptr);
 
-#ifndef NANO_TINY
-	/* FIXME: Hack which should go away ASAP */
-	if (strcasecmp(option,  "undo") == 0) {
-	    use_undo = TRUE;
-	    shortcut_init(0);
-	    continue;
-	}
-#endif
-
 	for (i = 0; rcopts[i].name != NULL; i++) {
 	    if (strcasecmp(option, rcopts[i].name) == 0) {
 #ifdef DEBUG
