@@ -1,4 +1,4 @@
-/* $Id: text.c 4397 2009-07-27 04:16:44Z astyanax $ */ 
+/* $Id: text.c 4407 2009-09-03 05:45:13Z astyanax $ */ 
 /**************************************************************************
  *   text.c                                                               *
  *                                                                        *
@@ -409,7 +409,7 @@ void redo_cut(undo *u) {
 	for (c = u->cutbuffer, t = openfile->current; c->next != NULL && t->next != NULL; ) {
 
 #ifdef DEBUG
-	fprintf(stderr, "Advancing, lineno  = %d, data = \"%s\"\n", t->lineno, t->data);
+	fprintf(stderr, "Advancing, lineno  = %zd, data = \"%s\"\n", t->lineno, t->data);
 #endif
 	    c = c->next;
 	    t = t->next;
@@ -812,7 +812,7 @@ bool execute_command(const char *command)
     if (f == NULL)
 	nperror("fdopen");
 
-    read_file(f, "stdin", TRUE);
+    read_file(f, 0, "stdin", TRUE);
 
     if (wait(NULL) == -1)
 	nperror("wait");
@@ -837,7 +837,7 @@ void add_undo(undo_type current_action)
     static undo *last_cutu = NULL; /* Last thing we cut to set up the undo for uncut */
     ssize_t wrap_loc;	/* For calculating split beginning */
 
-    if (!use_undo)
+    if (!ISSET(UNDOABLE))
 	return;
 
     /* Ugh, if we were called while cutting not-to-end, non-marked and on the same lineno,
@@ -943,7 +943,7 @@ void add_undo(undo_type current_action)
     }
 
 #ifdef DEBUG
-    fprintf(stderr, "fs->current->data = \"%s\", current_x = %d, u->begin = %d, type = %d\n",
+    fprintf(stderr, "fs->current->data = \"%s\", current_x = %zd, u->begin = %d, type = %d\n",
 			fs->current->data,  fs->current_x, u->begin, current_action);
     fprintf(stderr, "left add_undo...\n");
 #endif
@@ -962,14 +962,14 @@ void update_undo(undo_type action)
     int len = 0;
     openfilestruct *fs = openfile;
 
-    if (!use_undo)
+    if (!ISSET(UNDOABLE))
 	return;
 
 #ifdef DEBUG
-        fprintf(stderr, "action = %d, fs->last_action = %d,  openfile->current->lineno = %d",
+        fprintf(stderr, "action = %d, fs->last_action = %d,  openfile->current->lineno = %zd",
 		action, fs->last_action, openfile->current->lineno);
 	if (fs->current_undo)
-	    fprintf(stderr, "fs->current_undo->lineno = %d\n",  fs->current_undo->lineno);
+	    fprintf(stderr, "fs->current_undo->lineno = %zd\n",  fs->current_undo->lineno);
 	else
 	    fprintf(stderr, "\n");
 #endif
@@ -989,7 +989,7 @@ void update_undo(undo_type action)
     switch (u->type) {
     case ADD:
 #ifdef DEBUG
-        fprintf(stderr, "fs->current->data = \"%s\", current_x = %d, u->begin = %d\n",
+        fprintf(stderr, "fs->current->data = \"%s\", current_x = %zd, u->begin = %d\n",
 			fs->current->data,  fs->current_x, u->begin);
 #endif
         len = strlen(u->strdata) + 2;
